==> visual-2.2.2-sources.jar: com/zhuge/analysis/util/ActivityServicesUtils.java <==
package com.zhuge.analysis.util;

import android.app.ActivityManager;
import android.content.Context;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.List;

/**
 * Acitivity管理类
 * Created by kongmiao on 14-10-13.
 */
public class ActivityServicesUtils {
    private ActivityManager activityManager;

    public ActivityServicesUtils(Context context) {
        activityManager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
    }

    /**
     * 获取最近的任务列表
     */
    public JSONArray getRecentTasks() {
        JSONArray tasks = new JSONArray();
        try {
            List<ActivityManager.RunningAppProcessInfo> tasksInfo = activityManager.getRunningAppProcesses();
            int count = 0;
            for (ActivityManager.RunningAppProcessInfo task : tasksInfo) {
                try {
                    if (task.pkgList.length == 0)
                        continue;
                    if (task.processName.contains("com.android") || task.processName.equals("system"))
                        continue;
                    JSONObject taskObject = new JSONObject();
                    taskObject.put("pn", task.processName);
                    taskObject.put("top", count);
                    tasks.put(taskObject);
                    count++;
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return tasks;

    }

    /**
     * 获取当前进程名称
     */
    public String getMyProcessName() {

        int pid = android.os.Process.myPid();

        for (ActivityManager.RunningAppProcessInfo processInfo : activityManager.getRunningAppProcesses()) {
            if (processInfo.pid == pid) {
                return processInfo.processName;
            }
        }
        return "";
    }

    /**
     * 获取当前的任务列表
     */
    public String getForegroundPackage() {
        try {
            List<ActivityManager.RunningAppProcessInfo> tasksInfo = activityManager.getRunningAppProcesses();
            for (ActivityManager.RunningAppProcessInfo task : tasksInfo) {
                try {
                    return task.processName;
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;

    }
}

==> visual-2.3.1-sources.jar: com/zhuge/analysis/util/ActivityServicesUtils.java <==
package com.zhuge.analysis.util;

import android.app.ActivityManager;
import android.content.Context;

import org.json.JSONArray;
import org.json.JSONObject;

import java.util.List;

/**
 * Acitivity管理类
 * Created by kongmiao on 14-10-13.
 */
public class ActivityServicesUtils {
    private ActivityManager activityManager;

    public ActivityServicesUtils(Context context) {
        activityManager = (ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE);
    }

    /**
     * 获取最近的任务列表
     */
    public JSONArray getRecentTasks() {
        JSONArray tasks = new JSONArray();
        try {
            List<ActivityManager.RunningAppProcessInfo> tasksInfo = activityManager.getRunningAppProcesses();
            int count = 0;
            for (ActivityManager.RunningAppProcessInfo task : tasksInfo) {
                try {
                    if (task.pkgList.length == 0)
                        continue;
                    if (task.processName.contains("com.android") || task.processName.equals("system"))
                        continue;
                    JSONObject taskObject = new JSONObject();
                    taskObject.put("pn", task.processName);
                    taskObject.put("top", count);
                    tasks.put(taskObject);
                    count++;
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return tasks;

    }

    /**
     * 获取当前进程名称
     */
    public String getMyProcessName() {

        int pid = android.os.Process.myPid();
        List<ActivityManager.RunningAppProcessInfo> runningAppProcesses = activityManager.getRunningAppProcesses();
        if (null == runningAppProcesses){
            return "";
        }
        for (ActivityManager.RunningAppProcessInfo processInfo : runningAppProcesses) {
            if (processInfo.pid == pid) {
                return processInfo.processName;
            }
        }
        return "";
    }

    /**
     * 获取当前的任务列表
     */
    public String getForegroundPackage() {
        try {
            List<ActivityManager.RunningAppProcessInfo> tasksInfo = activityManager.getRunningAppProcesses();
            for (ActivityManager.RunningAppProcessInfo task : tasksInfo) {
                try {
                    return task.processName;
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;

    }
}
